//
//  GVAppDelegate.m
//  GVCustomControls
//
//  Created by User on 29.07.12.
//  Copyright (c) 2012 Vlad Gorloff. All rights reserved.
//

#import "GVAppDelegate.h"

@implementation GVAppDelegate

- (void)awakeFromNib
{
    /// Model
    self.model = [[GVModel alloc] init];

    
    /// Background
    //  See: http://vlads-audio.blogspot.com/2012/07/nsdrawninepartimage-alternative-using.html
    NSString*   imageName   = [[NSBundle mainBundle] pathForResource:@"MainBackground"
                                                              ofType:@"png"];
    [self.background setAllOffsets: 30];
    [self.background setBackgroundImage:imageName];

    
    /// Multiimage Knob
    //  See: http://vlads-audio.blogspot.com/2012/08/photoshop-360-export.html
    NSArray* images = [[NSBundle mainBundle] pathsForResourcesOfType:@"png"
                                                         inDirectory:@"images/Knob"];
    for (NSString *element in images)
    {
        NSImage* image = [[NSImage alloc] initWithContentsOfFile:element];
        if (image != nil)
        {
            [self.knob.images addObject:image];
        }
    }
    if (images.count > 0)
        self.knob.imageStep = 360/images.count;

    
    /// Establishing bindings between model and views (by normalized value).
    //  normalizedValue always in range [0...1]
    //  See:
    //  - http://developer.apple.com/library/mac/#documentation/Cocoa/Conceptual/CocoaBindings/Concepts/HowDoBindingsWork.html
    //  - http://www.tomdalling.com/blog/cocoa/implementing-your-own-cocoa-bindings
    [self.text bind:@"normalizedValue"
           toObject:self.controller
        withKeyPath:@"selection.gain"
            options:nil];

    [self.knob bind:@"normalizedValue"
           toObject:self.controller
        withKeyPath:@"selection.gain"
            options:nil];

}

- (void)applicationDidFinishLaunching:(NSNotification *)aNotification
{
    [self.model setGain: [NSNumber numberWithInteger:1]]; // Setting some default value to model
}

- (BOOL)applicationShouldTerminateAfterLastWindowClosed:(NSApplication *)sender
{
    [self.text unbind:@"normalizedValue"];
    [self.knob unbind:@"normalizedValue"];
    return true;
}

@end
