//
//  GVDecibelFormatter.m
//  GVFramework
//
//  Created by Vlad Gorloff on 22.08.12.
//  Copyright (c) 2012 Vlad Gorloff. All rights reserved.
//

#import "GVDecibelFormatter.h"
#import "GVCommonArithmetics.h"

@interface GVDecibelFormatter ()

-(NSString *) stringForNumbeValue:(NSNumber*)anNumber forEditing:(BOOL)flag;

@end

@implementation GVDecibelFormatter

-(id) init
{
    self = [super init];
    if (self)
    {
        self.minValue = -120;
        self.maxValue = 0;
    }
    return self;
}

-(NSString *) stringForNumbeValue:(NSNumber*)anNumber forEditing:(BOOL)flag
{
    NSString* format = (abs([anNumber intValue]) < 100) ? @"%.2f" : @"%.1f";
    if (flag == NO)
    {
//        if (abs([anNumber intValue]) > [GVCommonConstants decibelInfiniteValue])
//            format = ([anNumber intValue] < 0) ? @"-∞" : @"∞";

        format = [format stringByAppendingString:@" dB"];
    }
//    if([anNumber floatValue] == 0)
//        format = [@"-" stringByAppendingString:format];

    return [NSString stringWithFormat:format, [anNumber  floatValue]];
}

-(NSString *) stringForObjectValue:(id)anObject
{
    if (![anObject isKindOfClass:[NSNumber class]])
    {
        return nil;
    }

    return [self stringForNumbeValue:anObject forEditing:NO];
}

-(NSString *) editingStringForObjectValue:(id)anObject
{
    if (![anObject isKindOfClass:[NSNumber class]])
    {
        return nil;
    }

    return [self stringForNumbeValue:anObject forEditing:YES];
}

// @see NSFormatter Class Reference
-(BOOL) getObjectValue:(out id *)obj forString:(NSString *)string errorDescription:(out NSString **)error
{
    float floatResult  = 0;
    BOOL returnValue   = NO;

    NSScanner* scanner = [NSScanner scannerWithString:[string stringByReplacingOccurrencesOfString:@"," withString:@"." ]];
    if ([scanner scanFloat:&floatResult] && ([scanner isAtEnd]))
    {
        returnValue = YES;
        if (obj)
        {
            floatResult = GVPlaceFloatValueInRange(floatResult, (float)self.minValue, (float)self.maxValue);
            *obj        = [NSNumber numberWithFloat:floatResult];
        }
    }
    else
    {
        if (error)
            *error = NSLocalizedString(@"Couldn’t convert  to float", @"Error converting");
    }
    return returnValue;
}

@end
